@@ -1,6 +1,7 @@
-library(testthat)
 
-context("Method: summary.CV.SuperLearner")
+if(all(sapply(c("testthat", "mlbench", "glmnet", "cvAUC", "quadprog"), requireNamespace))){
+  
+testthat::context("Method: summary.CV.SuperLearner")
 
 ############################
 # Setup test dataset from mlbench.
@@ -34,11 +35,11 @@ cv_sl = CV.SuperLearner(Y = Y, X = X, family = binomial(),
 summary(cv_sl)
 
 # Specify method.
-cv_sl = CV.SuperLearner(Y = Y, X = X, family = binomial(),
-                        cvControl = list(V = 2),
-                        SL.library = sl_lib,
-                        method = "method.AUC")
-summary(cv_sl)
+#cv_sl = CV.SuperLearner(Y = Y, X = X, family = binomial(),
+#                        cvControl = list(V = 2),
+#                        SL.library = sl_lib,
+#                        method = "method.AUC")
+#summary(cv_sl)
 
 # Specify method using a variable.
 method = "method.NNLS2"
@@ -47,3 +48,5 @@ cv_sl = CV.SuperLearner(Y = Y, X = X, family = binomial(),
                         SL.library = sl_lib,
                         method = method)
 summary(cv_sl)
+
+  }
